
## Numpy and Scipy

- arrays, sparse matrices and linear algebra

## OSQP

OSQP ( Operator Splitting Quadratic Program ) is a quadratic programming algorithm supporting linear equalities and inequalities as constraints. Mouette relies on this solver for least-square problems when linear constraints are involved.

See the website https://osqp.org/ for a complete documentation